MessageDataRef

Struct MessageDataRef 

pub struct MessageDataRef<'a> {
    pub msg_hash: &'a [u8; 32],
    pub total_fee: u128,
    pub selector: &'a [u8; 32],
    pub sender_addr: &'a [u8],
    pub dest_addr: Pubkey,
    pub payload: &'a [u8],
    pub reserved: &'a [u8],
    pub transmitter_params: &'a [u8],
    pub src_chain_id: u128,
    pub src_block_number: u128,
    pub src_op_tx_id: &'a [[u8; 32]; 2],
}
Non-owned Message Data and message hash.

Fields

msg_hash: &'a [u8; 32]

The hash of the message.

total_fee: u128selector: &'a [u8; 32]

The encoded target function selector.

sender_addr: &'a [u8]

Sender contract address.

dest_addr: Pubkey

Destination contract address.

payload: &'a [u8]

The message payload.

reserved: &'a [u8]

Reserved field for future use.

transmitter_params: &'a [u8]

Additional transmitter parameters.

src_chain_id: u128

Source chain identifier.

src_block_number: u128

Proposal transaction block number.

src_op_tx_id: &'a [[u8; 32]; 2]

Proposal transaction ID.

Implementations

Source

impl MessageDataRef<'_>

pub unsafe fn load(msg_data_ptr: *const u8, msg_data_len: usize) -> Self

Parse MessageDataRef out of the raw pointer and length.

Safety
  • msg_data_ptr must point to at least msg_data_len bytes of valid, initialized memory that must remain alive and immutable for the duration of its use.